# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import template_cl
from . import account_move
from . import account_move_line
from . import account_tax
from . import l10n_latam_document_type
from . import res_company
from . import res_country
from . import res_currency
from . import res_partner
from . import res_partner_bank
from . import uom_uom
